package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Vaccinate;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description: 预防接种史未填写
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0029 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if(inputInfo.getBeHospitalizedDoc() == null){
            status.set("0");
            return;
        }
        List<Vaccinate> vaccinates = inputInfo.getBeHospitalizedDoc().getPastLabel().getVaccinates();
        if (ListUtil.isNotEmpty(vaccinates)) {
            if (vaccinates.stream().map(i -> i.getName()).filter(i -> StringUtil.isNotBlank(i)).count() > 0) {
                status.set("0");
                return;
            }
        }
        //台州结构化
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        Map<String, String> structureMap = beHospitalizedDoc.getStructureMap();
        if(StringUtils.isNotEmpty(structureMap.get("预防接种史"))){
            status.set("0");
            return;
        }
    }

}