package com.lantone.qc.kernel.catalogue.consultation;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.consultation.ConsultationApplicationDoc;
import com.lantone.qc.pub.model.doc.consultation.ConsultationDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : CON0536
 * @Description : 会诊申请单中会诊日期及时间填写不规范
 * @Author : 胡敬
 * @Date: 2020-03-28 10:20
 */
@Component
public class CON0536 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        List<ConsultationDoc> consultationDocs = inputInfo.getConsultationDocs();
        if (consultationDocs.size() == 0) {
            return;
        }
        for (ConsultationDoc consultationDoc : consultationDocs) {
            ConsultationApplicationDoc consultationApplicationDoc = consultationDoc.getConsultationApplicationDoc();
            if (consultationApplicationDoc == null) {
                continue;
            }
            Map<String, String> consultationResultStructureMap = consultationApplicationDoc.getStructureMap();
            String consultationDateStr = consultationResultStructureMap.get("会诊日期及时间");
            if (CatalogueUtil.isEmpty(consultationDateStr)) {
                continue;
            }
            Date consultationDate = StringUtil.parseDateTime(CatalogueUtil.removeSpecialChar(consultationDateStr)
                    , CatalogueUtil.processDateFormat(Content.dateFormats));

            if (null == consultationDate) {
                status.set("-1");
                return;
            }
        }
    }
}