package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ward.DirectorDoctorWardDoc;
import com.lantone.qc.pub.model.label.ThreeLevelWardLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0136
 * @Description : 上级医师（副主任医师/主任医师）首次查房无鉴别诊断
 * @Author : 胡敬
 * @Date: 2020-03-23 14:16
 */
@Component
public class THR0136 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getThreeLevelWardDocs().size() == 0) {
            status.set("0");
            return;
        }
        List<DirectorDoctorWardDoc> directorDocs = inputInfo.getThreeLevelWardDocs().get(0).getDirectorDoctorWardDocs();
        if (directorDocs.size() > 0) {
            DirectorDoctorWardDoc firstDirectDoc = directorDocs.get(0);
            //先取结构化数据判断
            Map<String, String> firstDirectStructureMap = firstDirectDoc.getStructureMap();
            String conditionRecord = firstDirectStructureMap.get("病情记录");
            if (StringUtil.isNotBlank(conditionRecord)) {
                if (conditionRecord.contains("鉴别")
                        || conditionRecord.contains("诊断明确")
                        || conditionRecord.contains("无需鉴别")) {
                    status.set("0");
                    return;
                }
            }
            ThreeLevelWardLabel firstDirectLabel = firstDirectDoc.getThreeLevelWardLabel();
            if (firstDirectLabel == null) {
                return;
            }

            if (firstDirectLabel.getDiffDiag().size() != 0 || StringUtil.isNotBlank(firstDirectLabel.getDiffDiagText())) {
                status.set("0");
            }
        }
    }
}